@@ -273,6 +273,12 @@
 (format *stderr* "~NC tleft ~NC~%" 20 #\- 20 #\-)
 (system "./repl tleft.scm")
 
+(format *stderr* "~NC tlamb ~NC~%" 20 #\- 20 #\-)
+(system "./repl tlamb.scm")
+
+(format *stderr* "~NC thook ~NC~%" 20 #\- 20 #\-)
+(system "./repl thook.scm")
+
 (format *stderr* "~NC tcase ~NC~%" 20 #\- 20 #\-)
 (system "./repl tcase.scm")
 
