@@ -48,6 +48,7 @@
 		     ("tobj.scm" . "v-obj")
 		     ("timp.scm" . "v-imp")
 		     ("tlamb.scm" . "v-lamb")
+		     ("thook.scm" . "v-hook")
 		     ))
 
 (define (last-callg)
@@ -85,40 +86,41 @@
 	 (list "snd -noinit" "make-index.scm")
 	 (list "repl" "tmock.scm")
 	 (list "repl" "tvect.scm")
+	 (list "repl" "timp.scm")
 	 (list "repl" "texit.scm")
 	 (list "repl" "s7test.scm")
-	 (list "repl" "timp.scm")
+	 (list "repl" "thook.scm")
 	 (list "repl" "lt.scm")
 	 (list "repl" "tauto.scm")
 	 (list "repl" "dup.scm")
+	 (list "repl" "tcopy.scm")
 	 (list "repl" "tload.scm")
-	 (list "repl" "tread.scm")
 	 (list "repl" "fbench.scm")
+	 (list "repl" "tread.scm")
 	 (list "repl" "trclo.scm")
 	 (list "repl" "titer.scm")
-	 (list "repl" "tcopy.scm")
 	 (list "repl" "tmat.scm")
 	 (list "repl" "tsort.scm")
 	 (list "repl" "teq.scm")
-	 (list "repl" "tmac.scm")
-	 (list "repl" "tio.scm")
 	 (list "repl" "tobj.scm")
+	 (list "repl" "tio.scm")
+	 (list "repl" "tmac.scm")
 	 (list "repl" "tclo.scm")
 	 (list "repl" "tlet.scm")
 	 (list "repl" "tcase.scm")
-	 (list "repl" "tmap.scm")
 	 (list "repl" "tfft.scm")
+	 (list "repl" "tmap.scm")
 	 (list "repl" "tshoot.scm")
 	 (list "repl" "tform.scm")
-	 (list "repl" "tnum.scm")
 	 (list "repl" "concordance.scm")
+	 (list "repl" "tnum.scm")
 	 (list "repl" "tlamb.scm")
 	 (list "repl" "tset.scm")
-	 (list "repl" "tlist.scm")
 	 (list "repl" "tmisc.scm")
+	 (list "repl" "tlist.scm")
 	 (list "repl" "tgsl.scm")
-	 (list "repl" "trec.scm")
 	 (reader-cond ((not (provided? 'gmp)) (list "repl" "tari.scm")))
+	 (list "repl" "trec.scm")
 	 (list "repl" "tleft.scm")
 	 (list "repl" "tgc.scm")
 	 (list "repl" "thash.scm")
